YustAuthServiceShared class

Constructors

YustAuthServiceShared()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

createYustUser({required Yust yust, required String firstName, required String lastName, required String email, required String id, required String authId, YustAuthenticationMethod? authenticationMethod, String? domain, YustGender? gender}) Future<YustUser>
tryLinkYustUser(Yust yust, String email, String authUserId, YustAuthenticationMethod? method) Future<bool>