yust library
Support for doing something awesome.
More dart docs go here.
Classes
- GoogleCloudHelpers
- Google Cloud (incl. Firebase) specific helpers used in other modules.
- IYustFileAccessService
- Handles file access and URL signing requests for files and folders.
- ServerNow
- ServerNow is a DateTime extension that returns the current date and time and uses a FieldValue.serverTimestamp() for the server.
- ServiceAccountCredentials
- Represents credentials for a service account.
- TraversalCurrentNode
- TraversalInfo
- TraverseObject
- UserAgentClient
- An HTTP client wrapper that sets a custom User-Agent header on every outgoing request.
- Yust
- Yust is the easiest way to connect a full stack Dart app to Firebase.
- YustAddress
- YustCdnConfiguration
- Configuration for a CDN.
- YustDatabaseService
- Handles database requests for Cloud Firestore.
- YustDatabaseServiceMocked
- A mock database service for storing docs.
- YustDmsCoordinates
- Class to store DMS coordinates as nullable properties.
- YustDoc
- A document, what can be saved to the Firestore database.
-
YustDocSetup<
T extends YustDoc> - The setup for a YustDoc is needed to read or save a document to the database.
- YustFieldTransform
- YustFile
- A binary file handled by database and file storage. A file is stored in Firebase Storage and linked to a document in the database. For offline caching a file can also be stored on the device.
- YustFileAccessGrant
- Access grant which shows the client how to access what files.
- YustFileAccessService
- YustFileAccessServiceMocked
- Mocked file access service.
- YustFilter
- The Filter class represents a document filter
- YustGeoLocation
- YustHelpers
- Yust helpers
- YustImage
- YustNotification
- A representation of a push notification.
- YustOrderBy
- The OrderBy class holds a field name and whether the sorting should be decreasing
- YustPushService
- Sends out Push notifications via Firebase Cloud Messaging
- YustPushServiceMocked
- Sends out Push notifications via Firebase Cloud Messaging
- YustRecursionMetaInfo
- YustRetryHelper
-
YustSnapshot<
T extends YustDoc> - YustUser
- The user model.
Enums
- AggregationType
- AuthState
- Represents the state of the user authentication.
- DatabaseLogAction
- GoogleCloudPlatform
- SnapshotState
- YustActionOnException
- The action to take if a exception occurs.
- YustAuthenticationMethod
- The authentication method of the user.
- YustCardinalDirection
- Enum for the four cardinal directions.
- YustFileThumbnailSize
- The size of the thumbnail.
- YustFilterComparator
- All types a filter can compare a brick value with a constant
- YustGender
- The gender of the user.
- YustLocationAppearance
- The appearance of a geo location
Extensions
- DateTimeExtension on DateTime
-
ListExtension
on List<
T> - ServerNowExtension on String
- ServiceAccountCredentialsExtension on ServiceAccountCredentials
-
Extension on ServiceAccountCredentials to derive the GCP project id
from the service account email (
<name>@<project-id>.iam.gserviceaccount.com). - StringExtension on String
Constants
- firestoreApiUrl → const String
Typedefs
- AggregationResult = ({int count, double? result})
-
DatabaseLogCallback
= void Function(DatabaseLogAction action, String documentPath, int count, {num? aggregationResult, String? id, List<
String> ? updateMask}) -
MockDB
= Map<
String, List< Map< >String, dynamic> > -
OnChangeCallback
= Future<
void> Function(String docPath, Map<String, dynamic> ? oldDocument, Map<String, dynamic> ? newDocument) - TraversalCallback = dynamic Function(TraversalCurrentNode currentNode)
- YustActionOnExceptionFn = YustActionOnException? Function(Object error, YustRecursionMetaInfo meta)
- Returns the action to take if a exception occurs. Can also throw to produce a new exception.
-
YustAggregatedStatisticsMap
= Map<
DatabaseLogAction, int> -
YustEnhancedStatisticsMap
= Map<
String, int> -
YustFileJson
= Map<
String, dynamic> -
YustFilesJson
= List<
YustFileJson> -
YustStatisticsMap
= Map<
String, Map< DatabaseLogAction, int> >